Acknowledgements
================

This version of pypuf is based on a development version with contributions due to (in chronological order)
Nils Wisiol, Christoph Graebnitz, Christopher Mühl, Benjamin Zengin, Tudor A. A. Soroceanu, and Niklas Pirnay.

Former versions of pypuf were used in a number of research articles [WP20]_ [WMPN19]_ [WBMS19]_ [WM19]_.
